@@ -3,13 +3,15 @@ import os as _os
 from collections import defaultdict
 from pathlib import Path
 
-__version__ = "2020.06.03"
-
-MODULE_PATH = Path(__file__).parents[0]
-
 # pleasant hack to support MSONable objects in Dash callbacks natively
 from monty.json import MSONable
 
+from crystal_toolkit.renderables import *
+
+__version__ = "2020.10.07"
+
+MODULE_PATH = Path(__file__).parents[0]
+
 
 def to_plotly_json(self):
     return self.as_dict()
@@ -28,19 +30,37 @@ with open(default_js) as handle:
     _DEFAULTS.update(json.loads(handle.read()))
 
 
-from crystal_toolkit.settings import SETTINGS as _SETTINGS
-
-
 def _repr_mimebundle_(self, include=None, exclude=None):
     """
     Render Scenes using crystaltoolkit-extension for Jupyter Lab.
     """
     # TODO: add Plotly, application/vnd.plotly.v1+json
+
+    help_text_ct = """If you see this text, the Crystal Toolkit Jupyter Lab \n
+extension is not installed. You can install it by running \n
+\"jupyter labextension install crystaltoolkit-extension\" \n
+from the same environment you run \"jupyter lab"\. \n\n
+"""
+
+    help_text_plotly = """If you see this text, the Plotly Jupyter Lab extension 
+is not installed, please consult Plotly documentation for information on how to 
+install.
+"""
+
+    # TODO: to be strict here, we could use inspect.signature
+    # and .return_annotation is either a Scene or a go.Figure respectively
+    # and also check all .parameters .kind.name have no POSITIONAL_ONLY
+    # in practice, fairly unlikely this will cause issues without strict checking
+
     if hasattr(self, "get_scene"):
         return {
             "application/vnd.mp.ctk+json": self.get_scene().to_json(),
-            # "application/json": self.as_dict(),
-            "text/plain": self.__repr__(),
+            "text/plain": help_text_ct + self.__repr__(),
+        }
+    elif hasattr(self, "get_plot"):
+        return {
+            "application/vnd.plotly.v1+json": self.get_plot().to_plotly_json(),
+            "text/plain": help_text_plotly + self.__repr__(),
         }
     else:
         return {"application/json": self.as_dict(), "text/plain": self.__repr__()}
@@ -49,6 +69,15 @@ def _repr_mimebundle_(self, include=None, exclude=None):
 MSONable._repr_mimebundle_ = _repr_mimebundle_
 
 
+def show_json(self):
+    from IPython.display import display_json
+
+    return display_json(self.as_dict(), raw=True)
+
+
+MSONable.show_json = show_json
+
+
 def _ipython_display_(self):
     """
     Render Scenes using crystaltoolkit-extension for Jupyter Lab.
@@ -58,13 +87,7 @@ def _ipython_display_(self):
     """
     from IPython.display import publish_display_data
 
-    if _SETTINGS.JUPYTER_LAB_PRINT_REPR:
-        print(self.__repr__())
-
     publish_display_data(self._repr_mimebundle_())
 
 
 MSONable._ipython_display_ = _ipython_display_
-
-# monkey-patching to add get_scene() methods to common objects
-from crystal_toolkit.renderables import *
