@@ -3,9 +3,8 @@ from abc import ABC, abstractmethod
 from ast import literal_eval
 from collections import defaultdict
 from itertools import chain
-from json import JSONDecodeError
-from json import dumps, loads
-from typing import Optional, Union, Dict, List, Set, Tuple
+from json import JSONDecodeError, dumps, loads
+from typing import Dict, List, Optional, Set, Tuple, Union
 
 import dash
 import dash_core_components as dcc
@@ -216,7 +215,6 @@ class MPComponent(ABC):
         self._all_ids = set()
         self._stores = {}
         self._initial_data = {}
-        self._kwarg_type_hints = {}
 
         self.links = links or {}
 
@@ -231,12 +229,25 @@ class MPComponent(ABC):
 
         self.logger = logging.getLogger(self.__class__.__name__)
 
-    def id(self, name: str = "default", is_kwarg: bool = False, idx=False) -> str:
+    def id(
+        self, name: str = "default", is_kwarg: bool = False, idx=False, hint=None
+    ) -> Union[str, Dict[str, str]]:
         """
         Generate an id from a name combined with the
         base id of the MPComponent itself, useful for generating
         ids of individual components in the layout.
 
+        In the special case of the id of an element that is used to re-construct
+        a keyword argument for a specific class, it will store information necessary
+        to reconstruct that keyword argument (e.g. its type hint and, in the case of
+        a vector or matrix, the corresponding index).
+
+        A hint could be a tuple for a numpy array of that shape, e.g. (3, 3) for a 3x3 matrix,
+        (1, 3) for a vector, or "literal" to parse kwarg value using ast.literal_eval, or "bool"
+        to parse a boolean value. In future iterations, we may be able to replace this with native
+        Python type hints. The problem here is being able to specify array shape where appropriate.
+
+
         Args:
             name: e.g. "default"
 
@@ -244,7 +255,12 @@ class MPComponent(ABC):
         """
 
         if is_kwarg:
-            return {"component_id": self._id, "kwarg_label": name, "idx": str(idx)}
+            return {
+                "component_id": self._id,
+                "kwarg_label": name,
+                "idx": str(idx),
+                "hint": str(hint),
+            }
 
         # if we're linking to another component, return that id
         if name in self.links:
@@ -402,32 +418,48 @@ Sub-layouts:  \n{layouts}"""
         default = np.full(shape, state.get(kwarg_label))
         default = np.reshape(default, shape)
 
-        self._kwarg_type_hints[kwarg_label] = shape
-
         def matrix_element(idx, value=0):
             # TODO: maybe move element out of the name
-            mid = self.id(kwarg_label, is_kwarg=True, idx=idx)
+            mid = self.id(kwarg_label, is_kwarg=True, idx=idx, hint=shape)
             if not is_int:
                 return dcc.Input(
                     id=mid,
                     inputMode="numeric",
+                    debounce=True,
                     className="input",
                     style={
                         "textAlign": "center",
                         # shorter default width if matrix or vector
-                        "width": "2.5rem"
-                        if (shape == (3, 3)) or (shape == (3,))
-                        else "5rem",
+                        "width": "5rem",
                         "marginRight": "0.2rem",
                         "marginBottom": "0.2rem",
                         "height": "1.5rem",
                     },
                     value=value,
                     persistence=True,
+                    type="number",
                     **kwargs,
                 )
             else:
-                return daq.NumericInput(id=mid, value=value, **kwargs)
+                return dcc.Input(
+                    id=mid,
+                    inputMode="numeric",
+                    debounce=True,
+                    className="input",
+                    style={
+                        "textAlign": "center",
+                        # shorter default width if matrix or vector
+                        "width": "5rem",
+                        "marginRight": "0.2rem",
+                        "marginBottom": "0.2rem",
+                        "height": "1.5rem",
+                    },
+                    value=value,
+                    persistence=True,
+                    type="number",
+                    step=1,
+                    **kwargs,
+                )
 
         # dict of row indices, column indices to element
         matrix_contents = defaultdict(dict)
@@ -467,11 +499,9 @@ Sub-layouts:  \n{layouts}"""
 
         default = state.get(kwarg_label) or False
 
-        self._kwarg_type_hints[kwarg_label] = "slider"
-
         if multiple:
             slider_input = dcc.RangeSlider(
-                id=self.id(kwarg_label, is_kwarg=True),
+                id=self.id(kwarg_label, is_kwarg=True, hint="slider"),
                 tooltip={"placement": "bottom"},
                 value=default,
                 persistence=True,
@@ -479,7 +509,7 @@ Sub-layouts:  \n{layouts}"""
             )
         else:
             slider_input = dcc.Slider(
-                id=self.id(kwarg_label, is_kwarg=True),
+                id=self.id(kwarg_label, is_kwarg=True, hint="slider"),
                 tooltip={"placement": "bottom"},
                 value=default,
                 persistence=True,
@@ -509,10 +539,8 @@ Sub-layouts:  \n{layouts}"""
 
         default = state.get(kwarg_label) or False
 
-        self._kwarg_type_hints[kwarg_label] = "bool"
-
         bool_input = dcc.Checklist(
-            id=self.id(kwarg_label, is_kwarg=True),
+            id=self.id(kwarg_label, is_kwarg=True, hint="bool"),
             style={"width": "5rem"},
             options=[{"label": "", "value": "enabled"}],
             value=["enabled"] if default else [],
@@ -545,11 +573,8 @@ Sub-layouts:  \n{layouts}"""
 
         default = state.get(kwarg_label)
 
-        self._kwarg_type_hints[kwarg_label] = "literal"
-
         option_input = dcc.Dropdown(
-            id=self.id(kwarg_label, is_kwarg=True),
-            style={"width": "12rem"},
+            id=self.id(kwarg_label, is_kwarg=True, hint="literal"),
             options=options if options else [],
             value=default,
             persistence=True,
@@ -571,10 +596,8 @@ Sub-layouts:  \n{layouts}"""
 
         default = state.get(kwarg_label) or {}
 
-        self._kwarg_type_hints[kwarg_label] = "dict"
-
         dict_input = dt.DataTable(
-            id=self.id(kwarg_label),
+            id=self.id(kwarg_label, is_kwarg=True, hint="dict"),
             columns=[
                 {"id": "key", "name": key_name},
                 {"id": "value", "name": value_name},
@@ -586,34 +609,25 @@ Sub-layouts:  \n{layouts}"""
 
         return add_label_help(dict_input, label, help_str)
 
-    @property
-    def kwarg_type_hints(self) -> Dict:
-        """
-        Valid keys are a tuple for a numpy array of that shape, e.g. (3, 3) for a 3x3 matrix,
-        (1, 3) for a vector, or "literal" to parse kwarg value using ast.literal_eval, or "bool"
-        to parse a boolean value.
-
-        In future iterations, we may be able to replace this with native Python type hints. The
-        problem here is being able to specify array shape where appropriate.
-
-        :return: e.g. {"scaling_matrix": (3, 3)} or {"sym_tol": "literal"}
-        """
-        return self._kwarg_type_hints
-
     def get_kwarg_id(self, kwarg_name) -> Dict:
         """
 
         :param kwarg_name:
         :return:
         """
-        return {"component_id": self._id, "kwarg_label": kwarg_name, "idx": ALL}
+        return {
+            "component_id": self._id,
+            "kwarg_label": kwarg_name,
+            "idx": ALL,
+            "hint": ALL,
+        }
 
     def get_all_kwargs_id(self) -> Dict:
         """
 
         :return:
         """
-        return {"component_id": self._id, "kwarg_label": ALL, "idx": ALL}
+        return {"component_id": self._id, "kwarg_label": ALL, "idx": ALL, "hint": ALL}
 
     def reconstruct_kwarg_from_state(self, state, kwarg_name):
         return self.reconstruct_kwargs_from_state(state)[kwarg_name]
@@ -635,11 +649,17 @@ Sub-layouts:  \n{layouts}"""
 
             kwarg_label = d["kwarg_label"]
 
-            k_type = self.kwarg_type_hints[d["kwarg_label"]]
+            try:
+                k_type = literal_eval(d["hint"])
+            except ValueError:
+                k_type = d["hint"]
+
             idx = literal_eval(d["idx"])
 
             # print(kwarg_label, k_type, idx, v)
 
+            # TODO: catch Exceptions here, and display validation error to user if incorrect kwargs supplied
+
             if isinstance(k_type, tuple):
                 # matrix or vector
                 if kwarg_label not in kwargs:
